@@ -2,7 +2,7 @@ package Data::Validate::Image;
 use strict;
 use warnings;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 $VERSION = eval $VERSION;
 
 use Image::Info;
@@ -34,8 +34,7 @@ sub validate{
         'file_ext' => $image_type->{'file_ext'},
     };
 
-    my $convert_installed = `which convert`;
-    if ( $convert_installed ){ #test if imagemagic is installed
+    if ( $self->_convert_installed ){ #test if imagemagic is installed
         my @frames = `convert -identify '${file}' /dev/null 2> /dev/null`;
 
         $image_info->{'frames'} = scalar( @frames );
@@ -50,6 +49,19 @@ sub validate{
     return $image_info;
 }
 
+sub _convert_installed{
+    my ( $self ) = @_;
+
+    my @paths = split( /:|;/, $ENV{PATH} );
+    foreach my $path ( @paths ){
+        if ( -e "${path}/convert" ){
+            return 1;
+        }   
+    }
+
+    return 0;
+}
+
 1;
 
 =head1 NAME
